Struct google_testing1::api::LauncherActivityIntent [−][src]
Specifies an intent that starts the main launcher activity.
This type is not used in any activity, and only used as part of another schema.