Struct google_testing1::api::ObbFile[][src]

pub struct ObbFile {
    pub obb: Option<FileReference>,
    pub obb_file_name: Option<String>,
}

An opaque binary blob file to install on the device before the test starts.

This type is not used in any activity, and only used as part of another schema.

Fields

obb: Option<FileReference>

Required. Opaque Binary Blob (OBB) file(s) to install on the device.

obb_file_name: Option<String>

Required. OBB file name which must conform to the format as specified by Android e.g. [main|patch].0300110.com.example.android.obb which will be installed into /Android/obb// on the device.