Trait google_testing1::client::CallBuilder [−][src]
Identifies types which represent builders for a particular resource method
Identifies types which represent builders for a particular resource method
impl<'a> CallBuilder for ApplicationDetailServiceGetApkDetailCall<'a>[src]impl<'a> CallBuilder for ProjectTestMatriceCancelCall<'a>[src]impl<'a> CallBuilder for ProjectTestMatriceCreateCall<'a>[src]impl<'a> CallBuilder for ProjectTestMatriceGetCall<'a>[src]impl<'a> CallBuilder for TestEnvironmentCatalogGetCall<'a>[src]