Struct google_testing1::AndroidDevice [−][src]
pub struct AndroidDevice {
pub locale: Option<String>,
pub android_version_id: Option<String>,
pub android_model_id: Option<String>,
pub orientation: Option<String>,
}A single Android device.
This type is not used in any activity, and only used as part of another schema.
Fields
locale: Option<String>
The locale the test device used for testing. Use the EnvironmentDiscoveryService to get supported options. Required
android_version_id: Option<String>
The id of the Android OS version to be used. Use the EnvironmentDiscoveryService to get supported options. Required
android_model_id: Option<String>
The id of the Android device to be used. Use the EnvironmentDiscoveryService to get supported options. Required
orientation: Option<String>
How the device is oriented during the test. Use the EnvironmentDiscoveryService to get supported options. Required