Struct google_testing1::AndroidDeviceList [−][src]
pub struct AndroidDeviceList {
pub android_devices: Option<Vec<AndroidDevice>>,
}A list of Android device configurations in which the test is to be executed.
This type is not used in any activity, and only used as part of another schema.
Fields
android_devices: Option<Vec<AndroidDevice>>
A list of Android devices Required