Struct google_testing1::AndroidMatrix [−][src]
pub struct AndroidMatrix {
pub android_version_ids: Option<Vec<String>>,
pub android_model_ids: Option<Vec<String>>,
pub locales: Option<Vec<String>>,
pub orientations: Option<Vec<String>>,
}A set of Android device configuration permutations is defined by the the cross-product of the given axes. Internally, the given AndroidMatrix will be expanded into a set of AndroidDevices.
Only supported permutations will be instantiated. Invalid permutations (e.g., incompatible models/versions) are ignored.
This type is not used in any activity, and only used as part of another schema.
Fields
android_version_ids: Option<Vec<String>>
The ids of the set of Android OS version to be used. Use the EnvironmentDiscoveryService to get supported options. Required
android_model_ids: Option<Vec<String>>
The ids of the set of Android device to be used. Use the EnvironmentDiscoveryService to get supported options. Required
locales: Option<Vec<String>>
The set of locales the test device will enable for testing. Use the EnvironmentDiscoveryService to get supported options. Required
orientations: Option<Vec<String>>
The set of orientations to test with. Use the EnvironmentDiscoveryService to get supported options. Required