Struct google_testing1::AndroidModel[][src]

pub struct AndroidModel {
    pub name: Option<String>,
    pub form: Option<String>,
    pub tags: Option<Vec<String>>,
    pub screen_density: Option<i32>,
    pub brand: Option<String>,
    pub id: Option<String>,
    pub supported_version_ids: Option<Vec<String>>,
    pub supported_abis: Option<Vec<String>>,
    pub screen_x: Option<i32>,
    pub screen_y: Option<i32>,
    pub manufacturer: Option<String>,
    pub codename: Option<String>,
}

A description of an Android device tests may be run on.

This type is not used in any activity, and only used as part of another schema.

Fields

The human-readable marketing name for this device model. Examples: "Nexus 5", "Galaxy S5" @OutputOnly

Whether this device is virtual or physical. @OutputOnly

Tags for this dimension. Examples: "default", "preview", "deprecated"

Screen density in DPI. This corresponds to ro.sf.lcd_density @OutputOnly

The company that this device is branded with. Example: "Google", "Samsung" @OutputOnly

The unique opaque id for this model. Use this for invoking the TestExecutionService. @OutputOnly

The set of Android versions this device supports. @OutputOnly

The list of supported ABIs for this device. This corresponds to either android.os.Build.SUPPORTED_ABIS (for API level 21 and above) or android.os.Build.CPU_ABI/CPU_ABI2. The most preferred ABI is the first element in the list.

Elements are optionally prefixed by "version_id:" (where version_id is the id of an AndroidVersion), denoting an ABI that is supported only on a particular version. @OutputOnly

Screen size in the horizontal (X) dimension measured in pixels. @OutputOnly

Screen size in the vertical (Y) dimension measured in pixels. @OutputOnly

The manufacturer of this device. @OutputOnly

The name of the industrial design. This corresponds to android.os.Build.DEVICE @OutputOnly