Struct google_testing1::AndroidRuntimeConfiguration [−][src]
pub struct AndroidRuntimeConfiguration {
pub orientations: Option<Vec<Orientation>>,
pub locales: Option<Vec<Locale>>,
}Configuration that can be selected at the time a test is run.
This type is not used in any activity, and only used as part of another schema.
Fields
orientations: Option<Vec<Orientation>>
The set of available orientations. @OutputOnly
locales: Option<Vec<Locale>>
The set of available locales. @OutputOnly