Struct google_testing1::Apk [−][src]
pub struct Apk {
pub package_name: Option<String>,
pub location: Option<FileReference>,
}An Android package file to install.
This type is not used in any activity, and only used as part of another schema.
Fields
package_name: Option<String>
The java package for the APK to be installed. Optional, value is determined by examining the application's manifest.
location: Option<FileReference>
The path to an APK to be installed on the device before the test begins. Optional