Struct google_testing1::CancelTestMatrixResponse
[−]
[src]
pub struct CancelTestMatrixResponse {
pub test_state: Option<String>,
}Response containing the current state of the specified test matrix.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- test matrices cancel projects (response)
Fields
test_state: Option<String>
The current rolled-up state of the test matrix. If this state is already final, then the cancelation request will have no effect.