Struct google_testing1::ClientInfoDetail
[−]
[src]
pub struct ClientInfoDetail {
pub key: Option<String>,
pub value: Option<String>,
}Key-value pair of detailed information about the client which invoked the test. For example {'Version', '1.0'}, {'Release Track', 'BETA'}
This type is not used in any activity, and only used as part of another schema.
Fields
key: Option<String>
The key of detailed client information. Required
value: Option<String>
The value of detailed client information. Required