Struct google_testing1::Date [] [src]

pub struct Date {
    pub month: Option<i32>,
    pub day: Option<i32>,
    pub year: Option<i32>,
}

Represents a whole calendar date, e.g. date of birth. The time of day and time zone are either specified elsewhere or are not significant. The date is relative to the Proleptic Gregorian Calendar. The day may be 0 to represent a year and month where the day is not significant, e.g. credit card expiration date. The year may be 0 to represent a month and day independent of year, e.g. anniversary date. Related types are google.type.TimeOfDay and google.protobuf.Timestamp.

This type is not used in any activity, and only used as part of another schema.

Fields

Month of year. Must be from 1 to 12.

Day of month. Must be from 1 to 31 and valid for the year and month, or 0 if specifying a year/month where the day is not significant.

Year of date. Must be from 1 to 9999, or 0 if specifying a date without a year.