Struct google_testing1::Environment [−][src]
pub struct Environment {
pub ios_device: Option<IosDevice>,
pub android_device: Option<AndroidDevice>,
}The environment in which the test is run.
This type is not used in any activity, and only used as part of another schema.
Fields
ios_device: Option<IosDevice>
An iOS device which must be used with an iOS test.
android_device: Option<AndroidDevice>
An Android device which must be used with an Android test.