Struct google_testing1::EnvironmentVariable [−][src]
A key-value pair passed as an environment variable to the test
This type is not used in any activity, and only used as part of another schema.
Fields
key: Option<String>
Key for the environment variable
value: Option<String>
Value for the environment variable