Struct google_testing1::GoogleAuto
[−]
[src]
pub struct GoogleAuto { /* fields omitted */ }Enables automatic Google account login. If set, the service will automatically generate a Google test account and add it to the device, before executing the test. Note that test accounts might be reused. Many applications show their full set of functionalities when an account is present on the device. Logging into the device with these generated accounts allows testing more functionalities.
This type is not used in any activity, and only used as part of another schema.