Struct google_testing1::GoogleCloudStorage
[−]
[src]
pub struct GoogleCloudStorage {
pub gcs_path: Option<String>,
}A storage location within Google cloud storage (GCS).
This type is not used in any activity, and only used as part of another schema.
Fields
gcs_path: Option<String>
The path to a directory in GCS that will eventually contain the results for this test. The requesting user must have write access on the bucket in the supplied path. Required