Struct google_testing1::IosTestSetup [−][src]
A description of how to set up an iOS device prior to a test.
This type is not used in any activity, and only used as part of another schema.
Fields
network_profile: Option<String>
Optional. The network traffic profile used for running the test. Available network profiles can be queried by using the NETWORK_CONFIGURATION environment type when calling TestEnvironmentDiscoveryService.GetTestEnvironmentCatalog.