Struct google_testing1::LauncherActivityIntent [−][src]
pub struct LauncherActivityIntent { /* fields omitted */ }Specifies an intent that starts the main launcher activity.
This type is not used in any activity, and only used as part of another schema.