Struct google_testing1::NetworkConfiguration [−][src]
pub struct NetworkConfiguration {
pub id: Option<String>,
pub down_rule: Option<TrafficRule>,
pub up_rule: Option<TrafficRule>,
}There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>
The unique opaque id for this network traffic configuration @OutputOnly
down_rule: Option<TrafficRule>
The emulation rule applying to the download traffic
up_rule: Option<TrafficRule>
The emulation rule applying to the upload traffic