Struct google_testing1::ProvidedSoftwareCatalog [−][src]
The currently provided software environment on the devices under test.
This type is not used in any activity, and only used as part of another schema.
Fields
orchestrator_version: Option<String>
A string representing the current version of Android Test Orchestrator that is provided by TestExecutionService. Example: "1.0.2 beta"