Struct google_testing1::ResultStorage
[−]
[src]
pub struct ResultStorage {
pub tool_results_history: Option<ToolResultsHistory>,
pub google_cloud_storage: Option<GoogleCloudStorage>,
pub tool_results_execution: Option<ToolResultsExecution>,
}Locations where the results of running the test are stored.
This type is not used in any activity, and only used as part of another schema.
Fields
tool_results_history: Option<ToolResultsHistory>
The tool results history that contains the tool results execution that results are written to.
Optional, if not provided the service will choose an appropriate value.
google_cloud_storage: Option<GoogleCloudStorage>
Required.
tool_results_execution: Option<ToolResultsExecution>
The tool results execution that results are written to. @OutputOnly