Struct google_testing1::RoboDirective
[−]
[src]
pub struct RoboDirective {
pub input_text: Option<String>,
pub resource_name: Option<String>,
pub action_type: Option<String>,
}Directs Robo to interact with a specific UI element if it is encountered during the crawl. Currently, Robo can perform text entry or element click.
This type is not used in any activity, and only used as part of another schema.
Fields
input_text: Option<String>
The text that Robo is directed to set. If left empty, the directive will be treated as a CLICK on the element matching the resource_name. Optional
resource_name: Option<String>
The android resource name of the target UI element For example, in Java: R.string.foo in xml: @string/foo Only the “foo” part is needed. Reference doc: https://developer.android.com/guide/topics/resources/accessing-resources.html Required
action_type: Option<String>
The type of action that Robo should perform on the specified element. Required.