Struct google_testing1::StartActivityIntent [−][src]
pub struct StartActivityIntent {
pub action: Option<String>,
pub uri: Option<String>,
pub categories: Option<Vec<String>>,
}A starting intent specified by an action, uri, and categories.
This type is not used in any activity, and only used as part of another schema.
Fields
action: Option<String>
Action name. Required for START_ACTIVITY.
uri: Option<String>
URI for the action. Optional.
categories: Option<Vec<String>>
Intent categories to set on the intent. Optional.