Struct google_testing1::TestDetails
[−]
[src]
pub struct TestDetails {
pub progress_messages: Option<Vec<String>>,
pub error_message: Option<String>,
}Additional details about the progress of the running test.
This type is not used in any activity, and only used as part of another schema.
Fields
progress_messages: Option<Vec<String>>
Human-readable, detailed descriptions of the test's progress. For example: "Provisioning a device", "Starting Test".
During the course of execution new data may be appended to the end of progress_messages. @OutputOnly
error_message: Option<String>
If the TestState is ERROR, then this string will contain human-readable details about the error. @OutputOnly