Struct google_testing1::TestEnvironmentCatalog
[−]
[src]
pub struct TestEnvironmentCatalog {
pub network_configuration_catalog: Option<NetworkConfigurationCatalog>,
pub android_device_catalog: Option<AndroidDeviceCatalog>,
}A description of a test environment.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get test environment catalog (response)
Fields
network_configuration_catalog: Option<NetworkConfigurationCatalog>
Supported network configurations
android_device_catalog: Option<AndroidDeviceCatalog>
Android devices suitable for running Android Instrumentation Tests.