Struct google_testing1::TestExecution [−][src]
pub struct TestExecution {
pub timestamp: Option<String>,
pub matrix_id: Option<String>,
pub state: Option<String>,
pub id: Option<String>,
pub environment: Option<Environment>,
pub test_specification: Option<TestSpecification>,
pub project_id: Option<String>,
pub tool_results_step: Option<ToolResultsStep>,
pub test_details: Option<TestDetails>,
}Specifies a single test to be executed in a single environment.
This type is not used in any activity, and only used as part of another schema.
Fields
timestamp: Option<String>
The time this test execution was initially created. @OutputOnly
matrix_id: Option<String>
Id of the containing TestMatrix. @OutputOnly
state: Option<String>
Indicates the current progress of the test execution (e.g., FINISHED). @OutputOnly
id: Option<String>
Unique id set by the backend. @OutputOnly
environment: Option<Environment>
How the host machine(s) are configured. @OutputOnly
test_specification: Option<TestSpecification>
How to run the test. @OutputOnly
project_id: Option<String>
The cloud project that owns the test execution. @OutputOnly
tool_results_step: Option<ToolResultsStep>
Where the results for this execution are written. @OutputOnly
test_details: Option<TestDetails>
Additional details about the running test. @OutputOnly