Struct google_testing1::ToolResultsStep
[−]
[src]
pub struct ToolResultsStep {
pub project_id: Option<String>,
pub execution_id: Option<String>,
pub step_id: Option<String>,
pub history_id: Option<String>,
}Represents a tool results step resource.
This has the results of a TestExecution.
This type is not used in any activity, and only used as part of another schema.
Fields
project_id: Option<String>
The cloud project that owns the tool results step. @OutputOnly
execution_id: Option<String>
A tool results execution ID. @OutputOnly
step_id: Option<String>
A tool results step ID. @OutputOnly
history_id: Option<String>
A tool results history ID. @OutputOnly