Struct google_testing1::Account [−][src]
pub struct Account {
pub google_auto: Option<GoogleAuto>,
}Identifies an account and how to log into it
This type is not used in any activity, and only used as part of another schema.
Fields
google_auto: Option<GoogleAuto>
An automatic google login account