Struct google_testing1::Environment
[−]
[src]
pub struct Environment {
pub android_device: Option<AndroidDevice>,
}The environment in which the test is run.
This type is not used in any activity, and only used as part of another schema.
Fields
android_device: Option<AndroidDevice>
An Android device which must be used with an Android test.