Struct google_testing1::TestSetup [−][src]
pub struct TestSetup {
pub account: Option<Account>,
pub files_to_push: Option<Vec<DeviceFile>>,
pub network_profile: Option<String>,
pub additional_apks: Option<Vec<Apk>>,
pub environment_variables: Option<Vec<EnvironmentVariable>>,
pub directories_to_pull: Option<Vec<String>>,
}A description of how to set up the Android device prior to running the test.
This type is not used in any activity, and only used as part of another schema.
Fields
account: Option<Account>
The device will be logged in on this account for the duration of the test. Optional
files_to_push: Option<Vec<DeviceFile>>
List of files to push to the device before starting the test.
Optional
network_profile: Option<String>
Optional. The network traffic profile used for running the test. Available network profiles can be queried by using the NETWORK_CONFIGURATION environment type when calling TestEnvironmentDiscoveryService.GetTestEnvironmentCatalog.
additional_apks: Option<Vec<Apk>>
APKs to install in addition to those being directly tested. Currently capped at 100. Optional
environment_variables: Option<Vec<EnvironmentVariable>>
Environment variables to set for the test (only applicable for instrumentation tests).
directories_to_pull: Option<Vec<String>>
List of directories on the device to upload to GCS at the end of the test; they must be absolute paths under /sdcard or /data/local/tmp. Path names are restricted to characters a-z A-Z 0-9 _ - . + and /
Note: The paths /sdcard and /data will be made available and treated as implicit path substitutions. E.g. if /sdcard on a particular device does not map to external storage, the system will replace it with the external storage path prefix for that device.
Optional